Package: pkgcond
Type: Package
Title: Classed Error and Warning Conditions
Version: 0.1.1
Authors@R: c(
    person("Andrew", "Redd", email="Andrew.Redd@hsc.utah.edu", role=c("aut", "cre")),
    person("R Documentation Task Force", role=c("aut"))
    )
Maintainer: Andrew Redd <Andrew.Redd@hsc.utah.edu>
Description: This provides utilities for creating classed error and warning
  conditions based on where the error originated.
License: GPL-2
Encoding: UTF-8
Depends: R(>= 3.5.0)
Imports: assertthat, methods
Suggests: covr, testthat
RoxygenNote: 7.1.1
Language: en-US
Collate: 'assert_that.R' 'conditions.R' 'comma_list.R' 'find_scope.R'
        'infix.R' 'skip_scope.R' 'suppress.R' 'translate.R'
URL: https://github.com/RDocTaskForce/pkgcond
BugReports: https://github.com/RDocTaskForce/pkgcond/issues
NeedsCompilation: no
Packaged: 2021-04-27 22:08:14 UTC; u0092104
Author: Andrew Redd [aut, cre],
  R Documentation Task Force [aut]
Repository: CRAN
Date/Publication: 2021-04-28 05:30:06 UTC
Built: R 4.6.0; ; 2026-04-25 18:02:27 UTC; unix
