# Generated by roxygen2: do not edit by hand

export("%!in%")
export("%<<%")
export("%<<<%")
export("%\\%")
export(._)
export(assert_that)
export(collapse)
export(collapse0)
export(comma_list)
export(condition)
export(find_scope)
export(pkg_error)
export(pkg_message)
export(pkg_warning)
export(skip_scope)
export(suppress_conditions)
export(suppress_messages)
export(suppress_warnings)
importFrom(methods,getPackageName)
importFrom(methods,is)
